@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,24 +24,24 @@
 #include <stdbool.h>
 #include <gtk/gtk.h>
 
-#include "gui.h"
+#include "callbacks.h"
 #include "main.h"
+#include "gui.h"
 #include "hash.h"
 #include "prefs.h"
 #include "list.h"
 
-void on_window_delete_event(GtkWidget *widget, GdkEvent *event, void *data)
+static void G_GNUC_NORETURN on_window_delete_event(void)
 {
 	exit(EXIT_SUCCESS);
 }
 
-void on_window_destroy(GtkObject *object, void *data)
+static void G_GNUC_NORETURN on_window_destroy(void)
 {
 	exit(EXIT_SUCCESS);
 }
 
-void on_window_size_request(GtkWidget *widget, GtkRequisition *requisition,
-	void *data)
+static void on_window_size_request(GtkWidget *widget)
 {
 	if (gui_window_maximised())
 		return;
@@ -54,10 +54,10 @@ void on_window_size_request(GtkWidget *widget, GtkRequisition *requisition,
 	}
 }
 
-void on_menuitem_file_activate(GtkAction *action, void *data)
+static void on_menuitem_file_activate(void)
 {
 	if (gui.busy) {
-		gtk_action_set_sensitive(gui_get_action("menuitem_save_as"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_save_as"), false);
 		return;
 	}
 
@@ -68,7 +68,7 @@ void on_menuitem_file_activate(GtkAction *action, void *data)
 				if (gtk_toggle_button_get_active(hash[i].button) &&
 					*gtk_entry_get_text(hash[i].entry))
 				{
-					gtk_action_set_sensitive(gui_get_action("menuitem_save_as"), true);
+					gtk_widget_set_sensitive(gui_get_widget("menuitem_save_as"), true);
 					return;
 				}
 			}
@@ -78,7 +78,7 @@ void on_menuitem_file_activate(GtkAction *action, void *data)
 				if (gtk_toggle_button_get_active(hash[i].button)) {
 					char *digest = list_get_digest(0, i);
 					if (digest != NULL && *digest) {
-						gtk_action_set_sensitive(gui_get_action("menuitem_save_as"), true);
+						gtk_widget_set_sensitive(gui_get_widget("menuitem_save_as"), true);
 						g_free(digest);
 						return;
 					}
@@ -89,10 +89,10 @@ void on_menuitem_file_activate(GtkAction *action, void *data)
 			g_assert_not_reached();
 	}
 
-	gtk_action_set_sensitive(gui_get_action("menuitem_save_as"), false);
+	gtk_widget_set_sensitive(gui_get_widget("menuitem_save_as"), false);
 }
 
-void on_menuitem_save_as_activate(GtkAction *action, void *data)
+static void on_menuitem_save_as_activate(void)
 {
 	// Create save dialog
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(
@@ -156,12 +156,12 @@ void on_menuitem_save_as_activate(GtkAction *action, void *data)
 	gtk_widget_destroy(GTK_WIDGET(chooser));
 }
 
-void on_menuitem_quit_activate(GtkAction *action, void *data)
+static void G_GNUC_NORETURN on_menuitem_quit_activate(void)
 {
 	exit(EXIT_SUCCESS);
 }
 
-void on_menuitem_edit_activate(GtkAction *action, void *data)
+static void on_menuitem_edit_activate(void)
 {
 	GtkWidget *widget = gtk_window_get_focus(GTK_WINDOW(gui_get_widget("window")));
 	bool selection, editable, clipboard;
@@ -173,21 +173,21 @@ void on_menuitem_edit_activate(GtkAction *action, void *data)
 		clipboard = gtk_clipboard_wait_is_text_available(
 			gtk_clipboard_get(GDK_NONE));
 
-		gtk_action_set_sensitive(gui_get_action("menuitem_cut"), selection && editable);
-		gtk_action_set_sensitive(gui_get_action("menuitem_copy"), selection);
-		gtk_action_set_sensitive(gui_get_action("menuitem_paste"), editable && clipboard);
-		gtk_action_set_sensitive(gui_get_action("menuitem_delete"), selection && editable);
-		gtk_action_set_sensitive(gui_get_action("menuitem_select_all"), true);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_cut"), selection && editable);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_copy"), selection);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_paste"), editable && clipboard);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_delete"), selection && editable);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_select_all"), true);
 	} else {
-		gtk_action_set_sensitive(gui_get_action("menuitem_cut"), false);
-		gtk_action_set_sensitive(gui_get_action("menuitem_copy"), false);
-		gtk_action_set_sensitive(gui_get_action("menuitem_paste"), false);
-		gtk_action_set_sensitive(gui_get_action("menuitem_delete"), false);
-		gtk_action_set_sensitive(gui_get_action("menuitem_select_all"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_cut"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_copy"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_paste"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_delete"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_select_all"), false);
 	}
 }
 
-void on_menuitem_cut_activate(GtkAction *action, void *data)
+static void on_menuitem_cut_activate(void)
 {
 	GtkEditable *widget = GTK_EDITABLE(gtk_window_get_focus(
 		GTK_WINDOW(gui_get_widget("window"))));
@@ -195,7 +195,7 @@ void on_menuitem_cut_activate(GtkAction *action, void *data)
 	gtk_editable_cut_clipboard(widget);
 }
 
-void on_menuitem_copy_activate(GtkAction *action, void *data)
+static void on_menuitem_copy_activate(void)
 {
 	GtkEditable *widget = GTK_EDITABLE(gtk_window_get_focus(
 		GTK_WINDOW(gui_get_widget("window"))));
@@ -203,7 +203,7 @@ void on_menuitem_copy_activate(GtkAction *action, void *data)
 	gtk_editable_copy_clipboard(widget);
 }
 
-void on_menuitem_paste_activate(GtkAction *action, void *data)
+static void on_menuitem_paste_activate(void)
 {
 	GtkEditable *widget = GTK_EDITABLE(gtk_window_get_focus(
 		GTK_WINDOW(gui_get_widget("window"))));
@@ -211,7 +211,7 @@ void on_menuitem_paste_activate(GtkAction *action, void *data)
 	gtk_editable_paste_clipboard(widget);
 }
 
-void on_menuitem_delete_activate(GtkAction *action, void *data)
+static void on_menuitem_delete_activate(void)
 {
 	GtkEditable *widget = GTK_EDITABLE(gtk_window_get_focus(
 		GTK_WINDOW(gui_get_widget("window"))));
@@ -219,7 +219,7 @@ void on_menuitem_delete_activate(GtkAction *action, void *data)
 	gtk_editable_delete_selection(widget);
 }
 
-void on_menuitem_select_all_activate(GtkAction *action, void *data)
+static void on_menuitem_select_all_activate(void)
 {
 	GtkEditable *widget = GTK_EDITABLE(gtk_window_get_focus(
 		GTK_WINDOW(gui_get_widget("window"))));
@@ -228,12 +228,12 @@ void on_menuitem_select_all_activate(GtkAction *action, void *data)
 	gtk_editable_select_region(widget, 0, -1);
 }
 
-void on_menuitem_prefs_activate(GtkAction *action, void *data)
+static void on_menuitem_prefs_activate(void)
 {
 	gtk_widget_show(gui_get_widget("dialog"));
 }
 
-void on_radiomenuitem_toggled(GtkToggleAction *toggleaction, void *data)
+static void on_radiomenuitem_toggled(void)
 {
 	switch (gui_view()) {
 		case VIEW_FILE:
@@ -283,7 +283,7 @@ void on_radiomenuitem_toggled(GtkToggleAction *toggleaction, void *data)
 	gui_clear();
 }
 
-void on_menuitem_about_activate(GtkAction *action, void *data)
+static void on_menuitem_about_activate(void)
 {
 	const char *license = {
 		"This program is free software; you can redistribute it and/or modify\n"
@@ -318,7 +318,7 @@ void on_menuitem_about_activate(GtkAction *action, void *data)
 			NULL);
 }
 
-void on_filechooserbutton_selection_changed(GtkFileChooser *chooser, void *data)
+static void on_filechooserbutton_selection_changed(GtkFileChooser *chooser)
 {
 	char *filename = gtk_file_chooser_get_filename(chooser);
 	gtk_widget_set_sensitive(gui_get_widget("button_hash"),
@@ -328,12 +328,12 @@ void on_filechooserbutton_selection_changed(GtkFileChooser *chooser, void *data)
 	gui_clear();
 }
 
-void on_entry_changed(GtkEditable *editable, void *data)
+static void on_entry_changed(void)
 {
 	gui_clear();
 }
 
-void on_toolbutton_add_clicked(GtkToolButton *toolbutton, void *data)
+static void on_toolbutton_add_clicked(void)
 {
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(
 		gtk_file_chooser_dialog_new(_("Select Files"), NULL,
@@ -361,17 +361,17 @@ void on_toolbutton_add_clicked(GtkToolButton *toolbutton, void *data)
 	gtk_widget_destroy(GTK_WIDGET(chooser));
 }
 
-void on_toolbutton_remove_clicked(GtkToolButton *toolbutton, void *data)
+static void on_toolbutton_remove_clicked(void)
 {
 	list_remove_selection();
 }
 
-void on_toolbutton_clear_clicked(GtkToolButton *toolbutton, void *data)
+static void on_toolbutton_clear_clicked(void)
 {
 	list_clear();
 }
 
-void on_button_hash_clicked(GtkButton *button, void *data)
+static void on_button_hash_clicked(void)
 {
 	bool success = true;
 
@@ -419,22 +419,63 @@ void on_button_hash_clicked(GtkButton *button, void *data)
 	gui_busy(false);
 }
 
-void on_button_stop_clicked(GtkButton *button, void *data)
+static void on_button_stop_clicked(void)
 {
-	hash_abort = true;
+	hash_stop = true;
 }
 
-void on_button_close_clicked(GtkButton *button, void *data)
+static void G_GNUC_NORETURN on_button_close_clicked(void)
 {
 	exit(EXIT_SUCCESS);
 }
 
-void on_dialog_delete_event(GtkWidget *widget, GdkEvent *event, void *data)
+static void on_dialog_delete_event(void)
 {
 	gui_dialog_hide();
 }
 
-void on_dialog_button_close_clicked(GtkButton *button, void *data)
+static void on_dialog_button_close_clicked(void)
 {
 	gui_dialog_hide();
 }
+
+void callbacks_init(void)
+{
+	const struct {
+		const char *obj;
+		const char *sig;
+		GCallback cb;
+	} callbacks[] = {
+		{ "window",					"delete-event",	on_window_delete_event },
+		{ "window",					"destroy",		on_window_destroy },
+		{ "window",					"size-request",	G_CALLBACK(on_window_size_request) },
+		{ "menuitem_file",			"activate",		on_menuitem_file_activate },
+		{ "menuitem_save_as",		"activate",		on_menuitem_save_as_activate },
+		{ "menuitem_quit",			"activate",		on_menuitem_quit_activate },
+		{ "menuitem_edit",			"activate",		on_menuitem_edit_activate },
+		{ "menuitem_cut",			"activate",		on_menuitem_cut_activate },
+		{ "menuitem_copy",			"activate",		on_menuitem_copy_activate },
+		{ "menuitem_paste",			"activate",		on_menuitem_paste_activate },
+		{ "menuitem_delete",		"activate",		on_menuitem_delete_activate },
+		{ "menuitem_select_all",	"activate",		on_menuitem_select_all_activate },
+		{ "menuitem_prefs",			"activate",		on_menuitem_prefs_activate },
+		{ "radiomenuitem_file",		"toggled",		on_radiomenuitem_toggled },
+		{ "radiomenuitem_text",		"toggled",		on_radiomenuitem_toggled },
+		{ "radiomenuitem_file_list","toggled",		on_radiomenuitem_toggled },
+		{ "menuitem_about",			"activate",		on_menuitem_about_activate },
+		{ "filechooserbutton",		"selection-changed",G_CALLBACK(on_filechooserbutton_selection_changed) },
+		{ "entry",					"changed",		on_entry_changed },
+		{ "toolbutton_add",			"clicked",		on_toolbutton_add_clicked },
+		{ "toolbutton_remove",		"clicked",		on_toolbutton_remove_clicked },
+		{ "toolbutton_clear",		"clicked",		on_toolbutton_clear_clicked },
+		{ "button_hash",			"clicked",		on_button_hash_clicked },
+		{ "button_stop",			"clicked",		on_button_stop_clicked },
+		{ "button_close",			"clicked",		on_button_close_clicked },
+		{ "dialog",					"delete-event",	on_dialog_delete_event },
+		{ "dialog_button_close",	"clicked",		on_dialog_button_close_clicked }
+	};
+
+	for (unsigned int i = 0; i < G_N_ELEMENTS(callbacks); i++)
+		g_signal_connect(gui_get_object(callbacks[i].obj), callbacks[i].sig,
+			callbacks[i].cb, NULL);
+}
