@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 
 #include "gui.h"
 #include "main.h"
+#include "callbacks.h"
 #include "hash.h"
 #include "list.h"
 #include "prefs.h"
@@ -67,25 +68,20 @@ static void init_hash_funcs(void)
 
 void gui_init(void)
 {
-	gui.xml = gtk_builder_new();
-	char *filename = g_build_filename(DATADIR, "gui.xml", NULL);
+	gui.builder = gtk_builder_new();
 
-	if (!gtk_builder_add_from_file(gui.xml, filename, NULL)) {
+	if (!gtk_builder_add_from_file(gui.builder, BUILDER_XML, NULL)) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
 			GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to read %s:\n%s"),
-			filename, g_strerror(errno));
+			BUILDER_XML, g_strerror(errno));
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		exit(EXIT_FAILURE);
 	}
 
-	g_free(filename);
-
-	gtk_builder_connect_signals(gui.xml, NULL);
+	callbacks_init();
 
 #if ENABLE_NLS
-	gtk_builder_set_translation_domain(gui.xml, PACKAGE);
-#else
-	gtk_builder_set_translation_domain(gui.xml, NULL);
+	gtk_builder_set_translation_domain(gui.builder, PACKAGE);
 #endif
 
 	init_hash_funcs();
@@ -95,7 +91,7 @@ GObject *gui_get_object(const char *name)
 {
 	g_assert(name);
 
-	GObject *obj = gtk_builder_get_object(gui.xml, name);
+	GObject *obj = gtk_builder_get_object(gui.builder, name);
 	if (!obj) {
 		printf("unknown object: \"%s\"\n", name);
 		exit(EXIT_FAILURE);
@@ -104,11 +100,6 @@ GObject *gui_get_object(const char *name)
 	return obj;
 }
 
-GtkAction *gui_get_action(const char *name)
-{
-	return GTK_ACTION(gui_get_object(name));
-}
-
 GtkWidget *gui_get_widget(const char *name)
 {
 	return GTK_WIDGET(gui_get_object(name));
@@ -116,17 +107,17 @@ GtkWidget *gui_get_widget(const char *name)
 
 int gui_view(void)
 {
-	if (gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(
+	if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(
 		gui_get_object("radiomenuitem_file"))))
 	{
 		return VIEW_FILE;
 
-	} else if (gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(
+	} else if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(
 		gui_get_object("radiomenuitem_text"))))
 	{
 		return VIEW_TEXT;
 
-	} else if (gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(
+	} else if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(
 		gui_get_object("radiomenuitem_file_list"))))
 	{
 		return VIEW_FILE_LIST;
@@ -175,17 +166,17 @@ void gui_busy(const bool busy)
 	gtk_widget_set_sensitive(gui_get_widget("hbox_output"), !busy);
 	gtk_widget_set_sensitive(gui_get_widget("toolbar"), !busy);
 
-	gtk_action_set_sensitive(gui_get_action("menuitem_prefs"), !busy);
-	gtk_action_set_sensitive(gui_get_action("radiomenuitem_text"), !busy);
-	gtk_action_set_sensitive(gui_get_action("radiomenuitem_file"), !busy);
-	gtk_action_set_sensitive(gui_get_action("radiomenuitem_file_list"), !busy);
+	gtk_widget_set_sensitive(gui_get_widget("menuitem_prefs"), !busy);
+	gtk_widget_set_sensitive(gui_get_widget("radiomenuitem_text"), !busy);
+	gtk_widget_set_sensitive(gui_get_widget("radiomenuitem_file"), !busy);
+	gtk_widget_set_sensitive(gui_get_widget("radiomenuitem_file_list"), !busy);
 
 	if (busy) {
 		gtk_widget_hide(gui_get_widget("button_hash"));
 		gtk_widget_show(gui_get_widget("button_stop"));
 		gtk_window_set_default(GTK_WINDOW(gui_get_widget("window")),
 			gui_get_widget("button_stop"));
-		gtk_action_set_sensitive(gui_get_action("menuitem_save_as"), false);
+		gtk_widget_set_sensitive(gui_get_widget("menuitem_save_as"), false);
 	} else {
 		gtk_widget_show(gui_get_widget("button_hash"));
 		gtk_widget_hide(gui_get_widget("button_stop"));
@@ -229,7 +220,7 @@ void gui_chooser_set_filename(const char *path)
 	gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(
 		gui_get_widget("filechooserbutton")), path);
 
-	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
 		gui_get_object("radiomenuitem_file")), true);
 }
 
