@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,14 +29,13 @@ enum {
 };
 
 struct {
-	GtkBuilder *xml;
+	GtkBuilder *builder;
 	bool busy;
 } gui;
 
 void gui_init(void);
 void gui_signal_connect(void);
 GObject *gui_get_object(const char *name);
-GtkAction *gui_get_action(const char *name);
 GtkWidget *gui_get_widget(const char *name);
 int gui_view(void);
 void gui_update(void);
