@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include "list.h"
 
 #define BUFFER_SIZE 4096 // File reading buffer
-#define PROGRESS_UPDATE 1024 // Bytes between progress bar updates
+#define PROGRESS_UPDATE 1024 // Reads between progress bar updates
 
 struct hash_s hash[HASH_N] = {
 	{ .type = MHASH_MD2,		.name = "MD2" },
@@ -72,7 +72,7 @@ static void hash_init(const int id)
 
 static char *hash_end(const int id)
 {
-	unsigned char *bin = mhash_end(hash[id].thread);
+	unsigned char *bin = mhash_end_m(hash[id].thread, g_malloc);
 	GString *digest = g_string_sized_new(128);
 
 	for (unsigned int i = 0; i < mhash_get_block_size(hash[id].type); i++)
@@ -110,15 +110,15 @@ bool hash_file(const char *filename)
 	g_io_channel_set_encoding(file, NULL, NULL);
 	filesize = get_filesize(filename);
 
-	for (gsize read = 0; !hash_abort; done++) {
-		g_io_channel_read_chars(file, buffer, BUFFER_SIZE, &read, NULL);
+	for (gsize just_read = 0; !hash_stop; done++) {
+		g_io_channel_read_chars(file, buffer, BUFFER_SIZE, &just_read, NULL);
 
-		if (G_UNLIKELY(!read))
+		if (G_UNLIKELY(!just_read))
 			break; // All done!
 
 		for (int i = 0; i < HASH_N; i++)
 			if (gtk_toggle_button_get_active(hash[i].button)) {
-				mhash(hash[i].thread, buffer, read);
+				mhash(hash[i].thread, buffer, just_read);
 				gtk_main_iteration_do(false);
 			}
 
@@ -133,12 +133,12 @@ bool hash_file(const char *filename)
 	}
 	g_io_channel_unref(file);
 
-	if (hash_abort) {
+	if (hash_stop) {
 		for (int i = 0; i < HASH_N; i++) {
 			if (gtk_toggle_button_get_active(hash[i].button))
 				g_free(hash_end(i));
 		}
-		hash_abort = false;
+		hash_stop = false;
 		return false;
 	}
 
