@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 #include <gtk/gtk.h>
 #include <mhash.h>
 
-#define HASH_N 27
-
 // Supported hash functions
 enum {
 	MD2, MD4, MD5,
@@ -37,6 +35,7 @@ enum {
 	SNEFRU128, SNEFRU256,
 	CRC32, CRC32B,
 	ADLER32,
+	HASH_N
 };
 
 struct hash_s {
@@ -48,7 +47,7 @@ struct hash_s {
 	GtkEntry *entry;
 } hash[HASH_N];
 
-bool hash_abort;
+bool hash_stop;
 
 char *hash_string(const char *string, const int id);
 bool hash_file(const char *filename);
