@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2009 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -112,7 +112,7 @@ void list_append_row(const char *path)
 
 	gtk_widget_set_sensitive(gui_get_widget("button_hash"), true);
 
-	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
 		gui_get_object("radiomenuitem_file_list")), true);
 
 	list_clear_digests();
